Monty Python's Flying Circus: Just the Words - Episode 22

# Episode Twenty-two

'How to recognize different parts of the body'
Bruces
Naughty bits
The man who contradicts people
Cosmetic surgery
Camp square-bashing
Cut-price airline
Batley Townswomen's Guild presents the first heart transplant
The first underwater production of 'Measure for Measure'
The death of Mary Queen of Scots
Exploding penguin on TV set
There's been a murder
Europolice Song Contest
'Bing Tiddle Tiddle Bong' (song)

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| The camera tracks past five gorgeous lovelies in bikini, all in send-up provocative pin-up poses. The sixth in the pan is the announcer at his desk also posing in a bikini (with bikini top).
Announcer | And now for something completely different.
| Cut to 'It's' man, also in bikini.
It's Man | It's...
| Cut to credit titles as normal, except that the last shot is the little chicken man who drags across a banner reading 'How to recognize different parts of the body'.
Voice Over | How to recognize different parts of the body.
| Hold long enough to read this new title before the foot comes down, stays in shot long enough for voice over to say:
Voice Over | Number one. The foot.
| A little arrow points to the foot simultaneously. Cut to picture of Venus de Milo (top half). Superimposed little white arrow pointing to shoulder.
Voice Over | Number two. The shoulder.
| Cut to picture of a foot cut off at the ankle. Cigarettes are parked in the top Superimposed arrow.
Voice Over | And number three. The other foot.
| Cut to profile picture of strange person (provided by Terry Gilliam) Superimposed arrow pointing to bridge of nose.
Voice Over | Number four. The bridge of the nose.
| Cut to picture, full length, of man wearing polka-dotted Bermuda shorts. Arrow superimposed points to shorts.
Voice Over | Number five. The naughty bits.
| Cut to picture of crooked elbow. Superimposed arrow pointing just above the elbow.
Voice Over | Number six. Just above the elbow.
| Cut to closer picture of different person in identical Bermuda shorts. Superimposed arrow pointing to top of groin.
Voice Over | Number seven. Two inches to the right of a very naughty bit indeed.
| Cut to close-up of a real knee. Arrow superimposed painting to knee.
Voice Over | Number eight. The kneecap.
| Pull back to reveal the knee belongs to First Bruce, an Australian in full Australian outback gear. We briefly hear a record of 'Waltzing Mathilda'. He is sitting in a very hot, slightly dusty room with low wicker chairs, a table in the middle, big centre fan, and old fridge.
Second Bruce | Goodday, Bruce!
First Bruce | Oh, Hello Bruce!
Third Bruce | How are yer Bruce?
First Bruce | Bit crook, Bruce.
Second Bruce | Where's Bruce?
First Bruce | He's not here, Bruce.
Third Bruce | Blimey, s'hot in here, Bruce.
First Bruce | S'hot enough to boil a monkey's bum!
Second Bruce | That's a strange expression, Bruce.
First Bruce | Well Bruce, I heard the Prime Minister use it. S'hot enough to boil a monkey's bum in 'ere, your Majesty,' he said and she smiled quietly to herself.
Third Bruce | She's a good Sheila, Bruce and not at all stuck up.
Second Bruce | Ah, here comes the Bossfella now! - how are you, Bruce?
| Enter fourth Bruce with English person, Michael
Fourth Bruce | Goodday, Bruce, Hello Bruce, how are you, Bruce? Gentlemen, I'd like to introduce a chap from pommie land... who'll be joining us this year here in the Philosophy Department of the University of Woolamaloo.
All | Goodday.
Fourth Bruce | Michael Baldwin - this is Bruce. Michael Baldwin - this is Bruce. Michael Baldwin - this is Bruce.
First Bruce | Is your name not Bruce, then?
Michael | No, it's Michael.
Second Bruce | That's going to cause a little confusion.
Third Bruce | Mind if we call you 'Bruce' to keep it clear?
Fourth Bruce | Well, Gentlemen, I think we'd better start the meeting. Before we start, though, I'll ask the padre for a prayer.
| First Bruce snaps a plastic dog-collar round his neck. They all lower their heads.
First Bruce | Oh Lord, we beseech thee, have mercy on our faculty, Amen!!
All | Amen!
Fourth Bruce | Crack the tubes, right! (Third Bruce starts opening beer cans) Er, Bruce, I now call upon you to welcome Mr. Baldwin to the Philosophy Department.
Second Bruce | I'd like to welcome the pommy bastard to God's own earth, and I'd like to remind him that we don't like stuck-up sticky-beaks here.
All | Hear, hear! Well spoken, Bruce!
Fourth Bruce | Now, Bruce teaches classical philosophy, Bruce teaches Haegelian philosophy, and Bruce here teaches logical positivism, and is also in charge of the sheepdip.
Third Bruce | What's does new Bruce teach?
Fourth Bruce | New Bruce will be teaching political science - Machiavelli, Bentham, Locke, Hobbes, Sutcliffe, Bradman, Lindwall, Miller, Hassett, and Benet.
Second Bruce | Those are cricketers, Bruce!
Fourth Bruce | Oh, spit!
Third Bruce | Howls of derisive laughter, Bruce!
Fourth Bruce | In addition, as he's going to be teaching politics, I've told him he's welcome to teach any of the great socialist thinkers, provided he makes it clear that they were wrong.
| They all stand up.
All | Australia, Australia, Australia, Australia, we love you. Amen!
| They sit down.
Fourth Bruce | Any questions?
Second Bruce | New Bruce - are you a pooftah?
Fourth Bruce | Are you a pooftah?
Michael | No!
Fourth Bruce | No right, well gentlemen, I'll just remind you of the faculty rules: Rule one - no pooftahs. Rule two, no member of the faculty is to maltreat the Abbos in any way whatsoever - if there's anybody watching. Rule three - no pooftahs. Rule four - I don't want to catch anyone not drinking in their room after lights out. Rule five - no pooftahs. Rule six - there is no rule six! Rule seven - no pooftahs. That concludes the reading of the rules, Bruce.
First Bruce | This here's the wattle - the emblem of our land. You can stick it in a bottle or you can hold it in your hand.
All | Amen!
Fourth Bruce | Gentlemen, at six o'clock I want every man-Bruce of you in the Sydney Harbour Bridge room to take a glass of sherry with the flying philosopher, Bruce, and I call upon you, padre, to close the meeting with a prayer.
First Bruce | Oh Lord, we beseech thee etc. etc. etc., Amen.
All | Amen!
First Bruce | Right, let's get some Sheilas.
| An Aborigine servant bursts in with an enormous tray full of enormous steaks.
Fourth Bruce | OK.
Second Bruce | Ah, elevenses.
Third Bruce | This should tide us over 'til lunchtime.
Second Bruce | Reckon so, Bruce.
First Bruce | Sydney Nolan! What's that! (points)
| Cut to dramatic close-up of Fourth Bruce's ear. Hold close-up. The superimposed arrow pointing to the ear.
Voice Over | Number nine. The ear.
| Cut to picture of big toe. Superimposed arrow.
Voice Over | Number ten. The big toe.
| Cut to picture of another man in Bermuda shorts. Superimposed arrow pointing at shorts.
Voice Over | Number eleven. More naughty bits.
| Cut to full length shot of lady in Bermuda shorts and Bermuda bra. Superimposed arrow on each side of her body. One points to the bra, one to the Bermuda shorts.
Voice Over | Number twelve. The naughty bits of a lady,
| Cut to picture of a horse wearing Bermuda shorts. Superimposed arrow.
Voice Over | Number thirteen. The naughty bits of a horse,
| Cut to picture of an ant. In the very corner of a blank area. It is very tiny. Superimposed enormous arrow.
Voice Over | Number fourteen. The naughty bits of an ant.
| Cut to picture of Reginald Maudling with Bermuda shorts, put on by Terry Gilliam, over his dark suit. Superimposed arrow pointing to shorts.
Voice Over | Number fifteen. The naughty bits of Reginald Maudling.
| Cut to close-up of false hand sticking out of a sleeve. Superimposed arrow.
Voice Over | Number sixteen. The hand.
| Pull back to reveal that the hand appears to belong to a standard interviewer in two shot. Chair set up with standard interviewee. The interviewer suddenly pulls the hand off, revealing that he has a hook. He throws the hand away and starts the interview.
Interviewer | Good evening. I have with me in the studio tonight Mr Norman St. John Polevaulter, who for the last few years has been contradicting people...Mr Polevaulter, why do you contradict people?
Polevaulter | I don't!
Interviewer | You told me that you did.
Polevaulter | I most certainly did not!
Interviewer | Oh. I see. I'll start again.
Polevaulter | No you won't!
Interviewer | Ssh! Mr Polevaulter I understand you don't contradict people.
Polevaulter | Yes I do!
Interviewer | And when didn't you start contradicting people?
Polevaulter | Well I did, in 1952.
Interviewer | 1952?
Polevaulter | 1947.
Interviewer | Twenty-three years ago.
Polevaulter | No!
| Cut to announcer at desk in farmyard. He is fondly holding a small pig.
Announcer | And so on and so on and so on. And now...
| Cut to picture of the Pope. Slight pause, so we think it might be something to do with the Pope. An arrow suddenly comes in above him pointing down at his head.
Voice Over | Number seventeen. The top of the head.
| Cut to picture of an indeterminate bit of flesh with a feather sticking out. Superimposed arrow pointing to feather.
Voice Over | Number eighteen...the feather, rare.
| Cut to profile of Raymond Luxury Yacht from next sketch who has an enormous false polystyrene nose. Superimposed arrow pointing at nose.
Voice Over | Number nineteen. The nose.
| A man sitting behind a desk in a Harley Street consulting room. Close-up of the name plate on desk in front of him. Although the camera does not reveal this for a moment, this name plate, about two inches high, continues all along the desk, off the side of it at the same height and halfway round the room. We start to track along this name plate on which is written: 'Professor Sir Adrian Furrows F.R.S. F.R.C.S. F.R.C.P. M.D.M.S. (Oxon), Mall Ph.D., M. Se. (Cantab), Ph.D. (Syd), ER.G.S., F.R.C.O.G., F. FM.R.C.S., M.S. (Birm), M.S. (Liv), M.S. (Guadalahara), M.S. (Karach), M.S. (Edin), B.A. (Chic), B. Litt. (Phil), D. Litt (Phil), D. Litt (Arthur and Lucy), D. Litt (Ottawa), D. Litt (All other places in Canada except Medicine Hat, B. Sc. 9 Brussels, Liege, Antwerp, Asse, (and Grower) '. There is a knock on the door.)
Specialist | Come in.
| The door opens and Raymond Luxury Yacht enters. He cannot walk straight to the desk as his passage is barred by the strip of wood carrying the degrees, but he discovers the special hinged part of it that opens like a door. Mr Luxury Yacht has his enormous polystyrene nose. It is a foot long.
Specialist | Ah! Mr Luxury Yacht. Do sit down, please.
Mr Luxury Yacht | Ah, no, no. My name is spelt 'Luxury Yacht' but it's pronounced 'Throatwobbler Mangrove'.
Specialist | Well, do sit down then Mr Throatwobbler Mangrove.
Mr Luxury Yacht | Thank you.
Specialist | Now, what seems to be the trouble?
Mr Luxury Yacht | Um, I'd like you to perform some plastic surgery on me.
Specialist | I see. And which particular feature of your anatomy is causing you distress?
Mr Luxury Yacht | Well, well for a long time now, in fact, even when I was a child ... I ... you know, whenever I left home to ... catch a bus, or... to catch a train... and even my tennis has suffered actually...
Specialist | Yes. To be absolutely blunt you're worried about your enormous hooter.
Mr Luxury Yacht | No!
Specialist | No?
Mr Luxury Yacht | Yes.
Specialist | Yes, and you want me to hack a bit off.
Mr Luxury Yacht | Please.
Specialist | Fine. It is a startler, isn't it? Er, do you mind if I... er.
Mr Luxury Yacht | What?
Specialist | Oh, no nothing, then, well, I'll just examine your nose. (he does so; as he examines it the nose comes off in his hand) Mr Luxury Yacht, this nose of yours is false. It's made of polystyrene and your own hooter's a beaut. No pruning necessary.
Mr Luxury Yacht | I'd still like the operation.
Specialist | Well, you've had the operation, you strange person.
Mr Luxury Yacht | Please do an operation.
Specialist | Well, all right, all right, but only ... if you come on a camping holiday with me.
Mr Luxury Yacht | He asked me! He asked me!
| Cut to lyrical film of Luxury Yacht and specialist, frolicking in countryside in slow motion. Cut to interviewer (the one with the hook) at desk.
Interviewer | Next week we'll be showing you how to pick up an architect, how to pull a prime minister, and how to have fun with a wholesale poulterer. But now the men of the Derbyshire Light Infantry entertain us with a precision display of bad temper.
Voice Over | Attention
| Eight soldiers in two ranks of four. They halt, and start to chant with precision.
Soldiers | My goodness me, I am in a bad temper today all right, two, three, damn, damn, two, three, I am vexed and ratty. (shake fists) Two, three, and hopping mad. (stamp feet)
| Cut to interviewer.
Interviewer | And next the men of the Second Armoured Division regale us with their famous close order swanning about.
| Cut to sergeant with eight soldiers.
Sergeant | Squad. Camp it ... up!
Soldiers | (mincing in unison) Oooh get her! Whoops! I've got your number ducky. You couldn't afford me, dear. Two three. I'd scratch your eyes out. Don't come the brigadier bit with us, dear, we all know where you've been, you military fairy. Whoops, don't look now girls the major's just minced in with that dolly colour sergeant, two, three, ooh-ho!
| Cut to interviewer.
Interviewer | And finally...
| ANIMATION: dancing generals, then the story of the killer cars. Cut to air terminal. Pan along official air-terminal-type signs saying BEA, TWA, Air India, BOAC, the Verrifast Plaine Company Ltd. Pan down to reveal a checking-in desk. A man with porter's cap comes in, carrying two bags. He is followed by Mr and Mrs Irrelevant. He puts their cases down, hangs around and gets a tip. He goes behind the counter, takes off his porter's hat, puts on an airline-pilot-type cap, and puts on a moustache. There is a vicar standing next to him with an eye patch.
Man | Morning sir, can I help you?
Mr Irrelevant | Er, yes, we've booked on your flight for America.
Man | Oh, we don't fly to America ... (vicar nudges him) Oh, the American flight... Er, on the plane ... oh yes, oh we do that, all right. Safe as houses, no need for panic.
Mrs Irrelevant | Is it really 37/6d?
Man | Thirty bob. I'm robbing myself.
Mr Irrelevant | Thirty bob!
Man | Twenty-five. Two quid the pair of yer. Er, that's without insurance.
Mr Irrelevant | Well, how much is it with insurance?
Man | Hundred and two quid. That's including the flight.
Mr Irrelevant | Do we really need insurance?
Man | No. (vicar nudges him) Yes, essential.
Mr Irrelevant | Well, we'll have it with insurance please.
Man | Right - do you want it with the body and one relative flown back, or you can have both bodies flown back and no relatives, or four relatives, no bodies, and the ashes sent by parcel post.
Mr Irrelevant | How long will it take?
Man | Er, let me put it this way - no idea.
Vicar | Six hours.
Mr Irrelevant | Six?
Man | Five, ten for the pair of you.
Mrs Irrelevant | Oh, is it a jet?
Man | Well, no ... It's not so much of a jet, it's more your, er, Triumph Herald engine with wings.
Mr Irrelevant | When are you taking off?.
Man | 3300 hours.
Mr Irrelevant | What?
Man | 2600 hours for the pair of you.
Mrs Irrelevant | What?
Man | Have the injections, you won't care.
Mr Irrelevant | What injections?
Man | Barley sugar injections. Calm you down. They're compulsory - Board of Trade. Promise. (he holds up his crossed fingers)
Mrs Irrelevant | Oh, I don't like the sound of injections.
Man | (making a ringing sound) Brrp, brrp. (picks up phone) Hello, yes right. (puts phone down) You've got to make your mind up straight away if you're coming or not.
Mr and Mrs Irrelevant | Yes.
Man | Right, you can't change your mind. I'll ring the departure lounge. (picks up phone) Hello? Two more on their way, Mrs Turpin.
| Cut to Mrs Turpin sitting in a suburban lounge. A big sign saying 'Intercontinental Arrivals', in airport writing, hangs from the ceiling. Mr and Mrs Irrelevant arrive and sit down.
Mrs Turpin | Now, the duty-free trolley is over there ... there's some lovely drop scones and there's duty-free broccoli and there's fresh eccles cakes. You're allowed two hundred each on the plane. (she picks up teacup and speaks into it) The Verrifast Plane Company announce the departure of flight one to over the hills and far away. Will passengers for flight one, please assemble at gate one. Passengers are advised that there is still plenty of time to buy eccles cakes.
| Man and vicar enter carrying a large wing.
Man | Nearly ready.
| They take the wing through. Hammering is heard.
Mrs Turpin | (speaking into cup) All passengers please get ready for their barley sugar injections.
| Japanese pilot comes in.
Kamikaze | Today we all take vow. Today we smash the enemy fleet... we smash, smash.
| Man and vicar grab him and take him back.
Mrs Turpin | That's Mr Kamikaze, the pilot, he's very nice really, but make sure he stays clear of battleships.
| Cut to stock film of battleships, steaming on the seas. Stirring music plays over.
Voice Over | There have been many stirring tales told of the sea and also some fairly uninteresting ones only marginally connected with it, like this one. Sorry, this isn't a very good announcement. Sorry.
| Cut from sea to announcer by his desk at the seaside.
Announcer | And here is the result of the 'Where to put Edward Heath's statue Competition. The winner was a Mr Ivy North who wins ten guineas and a visit to the Sailors Quarters.
| Cut to quick clip of the Battle of Pearl Harbor from show eleven, first series. Beginning with Eric blowing the whistle and the two sides rushing at each other. Cut back to announcer.
Announcer | That was last year's re-enactment of the Battle of Pearl Harbor performed by the Batley Townswomen's Guild. It was written, directed and produced by Mrs Rita Fairbanks.
| Cut to Rita Fairbanks on the beach.
Rita | Hello again.
Voice Over | And what are your ladies going to do for us this year?
Rita | Well, this year we decided to re-enact something with a more modern flavour. We had considered a version of Michael Stewart's speech on Nigeria and there were several votes on the Committee for a staging of Herr Willi Brandt's visit to East Germany, but we've settled instead for a dramatization of the first heart transplant. Incidentally my sister Madge will be playing the plucky little springbok pioneer Christian Barnard.
Voice Over | Well off we go, then with the Barley Townswomen's Guild re-enactment of the first heart transplant.
| Rita Fairbanks blows her whistle. The two groups of ladies rush at each other. They end up in the sea, rolling about splashing, and thumping each other with handbags.
Announcer | (his desk now surrounded by sea) The first heart transplant. But this is not the only open-air production here that has used the sea. Theatrical managers in this area have not been slow to appreciate the sea's tremendous dramatic value. And somewhere, out in this bay, is the first underwater production of 'Measure for Measure'.
| Expanse of sea water. Dubbed over this is muffled, watery Shakespearian blank verse. We zoom in. Two Shakespearian actors (Terry J and Michael) leap up. They take a deep breath and go under again. The dialogue carries on muted. Pull out to see a rowboat. Shakespearian characters are sitting there waiting for their cue. One of the two characters leaps up and shouts:
Character | Servant ho!
| He then goes underwater again. The servant in the boat steps into the water and goes under. Cut to announcer, now up to his waist in sea.
Announcer | The underwater version of 'Measure for Measure', and further out to sea 'Hello Dolly' is also doing good business.
| We see a buoy, on the top of which is a stiff piece of card which reads 'Hello Dolly, Tonight 7.30'. There is a muffled watery snatch of Hello Dolly. Swing round to a patch of open sea.
Announcer | ... and over there on the oyster beds Formula 2 car racing. (underwater noises of Formula 2 cars)
| ANIMATION: a racing car moves over a naked lady, going past a sign saying 'Pit Stop'. Close up of armpits. Superimposed little white arrow.
Voice Over | Number twenty. The armpits.
| Cut to picture of a person. Superimposed white arrow on the neck.
Voice Over | Number twenty-one. The bottom two-thirds of the nape of the neck.
| Cut to radio.
Voice Over | Number twenty-two. The nipple.
| Arrow indicates the tuning dial. Pull back. Two women are listening to the set. The announcer continues from the radio set.
Announcer's Voice | ...and that concludes the week's episode of 'How to Recognize Different Parts of the Body', adapted for radio by Ann Haydon-Jones and her husband, Pip. And now we present the first episode of a new radio drama series, 'The Death of Mary, Queen of Scots.' Part One: The Beginning.
| Theme music. 'Coronation Scot' as used in 'Paul Temple' for years.
Man's Voice | You are Mary, Queen of Scots?
Woman's voice | I am!
| There now follows a series of noises indicating that Mary is getting the shit knocked out of her. Thumps, bangs, slaps, pneumatic drilling, sawing, flogging, shooting, all interlaced with Mary's screams. The two women listen calmly. After a few seconds: fade as the signature tune 'Coronation Scot' is brought up loudly to denote ending of episode.
Radio Announcer | Episode two of 'The Death of Mary, Queen of Scots', can be heard on Radio 4 almost immediately.
| One of the women goes over to the set and switches it over. As she goes back to her seat from the radio we hear the theme music again, fading out as the sounds of violence and screaming start again and continue unabated in vigour.
Man's Voice | I think she's dead.
Woman's voice | No I'm not!
| After a time, sounds of violence and screaming start again rapidly fading under the tune of 'Coronation Scot'.
Announcer's Voice | That was episode two of 'The Death of Mary, Queen of Scots', adapted for radio by Bernard Hollowood and Brian London. And now, Radio Four will explode. (the radio explodes)
First Pepperpot | We'll have to watch the telly then.
Second Pepperpot | Yes
| The pepperpots swivel round to look at the TV set in the corner of the room.
First Pepperpot | What's that on the tellevision then?
Second Pepperpot | Looks like a penguin.
| On the TV set there is indeed a penguin. It sits contendedly looking at them in a stuffed sort of way. There is nothing on the screen.
First Pepperpot | No, no, no, I didn't mean what's on the television set, I meant what programme.
Second Pepperpot | Oh.
| The second pepperpot goes to the TV, switches it on and returns to her chair. The set takes a long time to warm up and produce a picture. During this pause the following conversation takes place:
Second Pepperpot | It's funny that penguin being there innit? What's it doing there?
First Pepperpot | Standing.
Second Pepperpot | I can see that!
First Pepperpot | If it lays an egg, it will fall down the back of the television set.
Second Pepperpot | We'll have to watch that. Unless it's a male.
First Pepperpot | Ooh, I never thought of that.
Second Pepperpot | Yes, looks fairly butch.
First Pepperpot | Per'aps it's from next door.
Second Pepperpot | Penguins don't come from next door, they come from the Antarctic.
First Pepperpot | Burma.
Second Pepperpot | Why did say Burma?
First Pepperpot | I panicked.
Second Pepperpot | Oh. Perhaps it's from the zoo.
First Pepperpot | Which zoo?
Second Pepperpot | How should I know which zoo? I'm not Doctor bloody Bernowski.
First Pepperpot | How does Doctor Bernowski know which zoo it came from?
Second Pepperpot | He knows everything.
First Pepperpot | Oooh, I wouldn't like that, that'd take all the mystery out of life. Anyway, if it came from the zoo, it would have 'property of the zoo' stamped on it.
Second Pepperpot | No it wouldn't. They don't stamp animals 'property of the zoo'. You can't stamp a huge lion.
First Pepperpot | They stamp them when they're small.
Second Pepperpot | What happens when they moult?
First Pepperpot | Lions don't moult.
Second Pepperpot | No, but penguins do. There, I've run rings around you logically.
First Pepperpot | Oh, intercourse the penguin.
| On the TV screen there now appears an announcer.
TV Announcer | It's just gone 8 o'clock and time for the penguin on top of your television set to explode.
| The penguin on top of the set now explodes.
First Pepperpot | How did he know that was going to happen?!
TV Announcer | It was an inspired guess. And now...
| Cut to picture of a shin.
Voice Over | Number twenty-three. The shin.
| Cut to Reginald Maulding.
Voice Over | Number twenty-four. Reginald's Maulding's shin
| Cut to Gilliam-type open-head picture, with arrow superimposed.
Voice Over | Number twenty-five. The brain.
| Cut to picture of Magaret Thatcher. Arrow points to her knee.
Voice Over | Number twenty-six. Magaret Thatcher's brain.
| Cut to a fairly wide still picture of cricket match in progress. Batsman, bowler, ring of fielders all have polka-dotted Bermuda shorts. Little arrows point to each pair of Bermuda shorts.
Voice Over | Number twenty-seven. More naughty bits.
| Cut to picture of the cabinet at a table. Arrows point down below the table to their naughty bits.
Voice Over | Number twenty-eight. The naughty bits of the cabinet.
| Cut to studio shot of the next set. Interior of country house. Superimposed arrow.
Voice Over | Number twenty-nine. The interior of a country house.
| Cut to room, with doctor, mother, and son.
Doctor | That's not a part of the body.
Mother | No, it's a link though.
Son | I didn't think it was very good.
Doctor | No, it's the end of the series, they must be running out of ideas.
| Inspector Muffin the Mule bursts through the door.
Muffin | All right, don't anybody move, there's been a murder.
Mother | A murder?
Muffin | No... no ... not a murder... no what's like a murder but begins with B?
Son | Birmingham.
Muffin | No ... no ... no ... no ... no...
Doctor | Burnley?
Muffin | Burnley - that's right! Burnley in Lancashire. There's been a Burnley.
Son | Burglary.
Muffin | Burglary. Yes, good man. Burglary - that's it, of course. There's been a burglary.
Doctor | Where?
Muffin | In the back, just below the rib.
Doctor | No - that's murder.
Muffin | Oh... er no... in the band... In the bat... Barclays bat.
Son | Barclays Bank?
Muffin | Yes. Nasty business - got away with £23,000.
Son | Any clues?
Muffin | Any what?
Son | Any evidence as to who did it?
Muffin | (sarcastically) Any clues, eh? Oh, we don't half talk posh, don't we? I suppose you say 'ehnvelope' and 'larngerie' and 'sarndwiches on the settee'! Well this is a murder investigation, young man, and murder is a very serious business.
Doctor | I thought you said it was a burglary.
Muffin | Burglary is almost as serious a business as murder. Some burglaries are more serious than murder. A burglary in which someone gets stabbled is murder! So don't come these petty distinctions with me. You're as bad as a judge. Right, now! The first thing to do in the event of a breach of the peace of any kind, is to... go... (pause) and ... oh, sorry, sorry, I was miles away.
Doctor | Ring the police?
Muffin | Ring the police. Yes, that's a good idea. Get them over here fast ... no, on second thoughts, get them over here slowly, so they don't drop anything.
Mother | Shall I make us all a cup of tea?
Muffin | Make what you like, Boskovitch - it won't help you in court.
Mother | I beg your pardon?
Muffin | I'm sorry, sorry. That's the trouble with being on two cases at once. I keep thinking I've got Boskovitch cornered and in fact I'm investigating a Burnley.
Son | Burglary.
Muffin | Burglary! Yes - good man.
| Sound of police siren and sound of cars drawing up outside.
Doctor | Who's Boskovitch?
Muffin | Hah! Boskovitch is a Russian scientist who is passing information to the Russians.
Son | Classified information?
Muffin | Oh, there he goes again! 'Classified information'! Oh, sitting on the 'settee' with our 'scones' and our 'classified information'!
| The door opens and a plainclothes detective plus ten PCs (the Fred Tomlinson Singers) enter.
Muffin | Ah! Hello, Duckie.
Duckie | Hello, sir. How are you?
Muffin | I'm fine thanks. How are you?
Duckie | Well, sir, I'm a little bit moody today, sir.
Muffin | Why's that, Duckie?
Duckie | Because...
| Rhythm combo starts up out of vision and Dective Duckie sings. SUPERIMPOSED CAPTION: 'SGT DUCKIE'S SONG'
Duckie | I'm a little bit sad and lonely Now my baby's gone away... I'm feeling kinda blue Don't know just what to do I feel a little sad today.
Chorus of PCs | He's a little bit sad and lonely Now his baby's gone away He's feeling kinda blue He don't know just what to do He's not feeling so good today.
Duckie | (solo) When I smile The sun comes flooding in But when I'm sad It goes behind the clouds again.
Chorus | He's a little bit sad and lonely Now his baby's gone away He's feeling kinda (they stop abruptly and say): etcetera, etcetera. (applause)
Muffin | A lovely song, Duckie.
| Eurovision girl comes in.
Girl | And that's the final entry. La dernière entrée. Das final entry. And now, guten abend. Das scores. The scores. Les scores. Dei scores. Oh! Scores. Ha! Scores! (cut to scoreboard in Chinese) Yes, Monaco is the winner - hall Monaco is the linner- oh yes, man, Monaco's won de big prize, bwana ... and now, here is Chief Inspector Jean-Paul Zatapathique with the winning song once again.
| The accompaniment starts as the singers hum the intro. Cut to flashy Eurovision set. Zatapathique steps onto podium.
Voice Over | (hushed tone) And so, Inspector Zatapathique, the forensic expert from the Monaco Murder Squad sings his song 'Bing Tiddle Tiddle Bong'.
Zatapathique | (spoken) Quoi? Quoi? Tout le monde, quoi? ... mais, le monde ... d'habitude ... mais ... je pense ...
Zatapathique and Singers | Bing tiddle tiddle bang Bing tiddle fiddle bing Bing fiddle fiddle tiddle tiddle Bing fiddle tiddle tiddle BONG!
| Credits over. Zatapathique finishes and bends over exhausted. An arrow indicates his rear.
Voice Over | Number thirty-one. The end.
| CAPTION: 'THE END'